aboutsummaryrefslogtreecommitdiff
path: root/net/wireless/core.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/wireless/core.h')
-rw-r--r--net/wireless/core.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/wireless/core.h b/net/wireless/core.h
index 4f2e0fe38ce..f3ab00cbf76 100644
--- a/net/wireless/core.h
+++ b/net/wireless/core.h
@@ -70,7 +70,7 @@ bool wiphy_idx_valid(int wiphy_idx)
return (wiphy_idx >= 0);
}
-extern struct mutex cfg80211_drv_mutex;
+extern struct mutex cfg80211_mutex;
extern struct list_head cfg80211_drv_list;
struct cfg80211_internal_bss {
@@ -89,13 +89,13 @@ struct cfg80211_internal_bss {
* the driver's mutex!
*
* This means that you need to call cfg80211_put_dev()
* before being allowed to acquire &cfg80211_drv_mutex!
*
* This is necessary because we need to lock the global
* mutex to get an item off the list safely, and then
* we lock the drv mutex so it doesn't go away under us.
*
* We don't want to keep cfg80211_drv_mutex locked
* for all the time in order to allow requests on
* other interfaces to go through at the same time.
*
@@ -89,13 +89,13 @@ struct cfg80211_internal_bss {
*
* This means that you need to call cfg80211_put_dev()
- * before being allowed to acquire &cfg80211_drv_mutex!
+ * before being allowed to acquire &cfg80211_mutex!
*
* This is necessary because we need to lock the global
@@ -89,13 +89,13 @@ struct cfg80211_internal_bss {
* we lock the drv mutex so it doesn't go away under us.
*
- * We don't want to keep cfg80211_drv_mutex locked
+ * We don't want to keep cfg80211_mutex locked
* for all the time in order to allow requests on
* other interfaces to go through at the same time.